@@ -26,8 +26,8 @@ if 'milestone_4_p2.txt' in os.listdir('.'):
             else:
                 mark_incomplete(task_id, errors[task_name])
                 break
-        if n_task == len(task_name_list) - 1:
-            print('All tasks in milestone 3 completed!')
+        if n_task == len(task_name_list):
+            print('All tasks in milestone 4 completed!')
         else:
             for task_name, task_id in task_name_list[n_task + 1:]:
                 mark_incomplete(task_id)
